--[[
	Look Lock

	By Mugendai

	This mod allows a button to be mapped to allow
	freelook to become locked on.
	It also allows for the option to remap the left
	and right mouse buttons to act different when
	in Look Lock mode.
	
	Thanks go to Skrag and iecur for info on how to do this.
   ]]
   
-- Set this to 1 if you want the mouse buttons remapped to use the modified versions.
LookLockRemapOn = 0;

-- General Cosmos Registration Functions
function LookLock_RegisterCosmos()

	--
	-- Check for the functions before calling them. 
	--
	-- This will make it possible to keep the add-on
	-- independent of Cosmos Core
	-- 
	if ( Cosmos_RegisterConfiguration ) then 

		Cosmos_RegisterConfiguration(
			"COS_LOOKLOCK_HEADER",
			"SEPARATOR",
			LOOKLOCK_CONFIG_HEADER,
			LOOKLOCK_CONFIG_HEADER_INFO
			);
		Cosmos_RegisterConfiguration(
			"COS_LOOKLOCK_TOGGLE", -- CVAr
			"CHECKBOX",
			LOOKLOCK_CONFIG_REMAP_ONOFF,
			LOOKLOCK_CONFIG_REMAP_ONOFF_INFO,
			LookLock_Remap_Toggle,
			1
			);
	else
		SlashCmdList["LOOKLOCKSLASH"] = LookLock_ChatCommandHandler;
		SLASH_LOOKLOCKSLASH1 = "/looklockremap";
		SLASH_LOOKLOCKSLASH2 = "/llremap";
	end

	-- Add /commands
	if ( Cosmos_RegisterChatCommand ) then
		local LookLockCommands = {"/looklockremap","/llremap"};
		Cosmos_RegisterChatCommand (
			"LOOKLOCK_COMMANDS", -- Some Unique Group ID
			LookLockCommands, -- The Commands
			LookLock_ChatCommandHandler,
			LOOKLOCK_CHAT_COMMAND_INFO -- Description String
			);	
	end
end

-- LookLock /looklockremap command handler
function LookLock_ChatCommandHandler(msg)
	local found=0;
	msg = string.lower(msg);
	
	-- Toggle appropriately
	if (string.find(msg, 'on')) then
		LookLock_Remap_Toggle(1);
	else
		if (string.find(msg, 'off')) then
			LookLock_Remap_Toggle(0);
		else
			LookLock_Remap_Toggle(-1);
		end
	end
end

-- Enable/Disable Remapping the mouse buttons
function LookLock_Remap_Toggle(toggle) 
	if ( toggle == -1 ) then 
		if (LookLockRemapOn == 1) then
			dotoggle = 0;
		else
			dotoggle = 1;
		end
	else
		dotoggle = toggle;
	end
	LookLockRemapOn = dotoggle;
	local msg = LOOKLOCK_CHAT_REMAP_ON;
	if ( dotoggle == 1 ) then 
		SetBinding("BUTTON2","LOOKLOCKACTION");
		SetBinding("BUTTON1","LOOKLOCKCAMERA");
	else
		SetBinding("BUTTON2","TURNORACTION");
		SetBinding("BUTTON1","CAMERAORSELECTORMOVE");
		msg = LOOKLOCK_CHAT_REMAP_OFF;
	end
	
	if ( Cosmos_RegisterConfiguration == nil ) then 
		RegisterForSave("LookLockRemapOn");	
		local info = ChatTypeInfo["SYSTEM"];
    		ChatFrame1:AddMessage(msg, info.r, info.g, info.b, info.id);
	end
end


-- OnFoo Functions
function LookLock_OnLoad()
	this:RegisterEvent("UPDATE_BINDINGS");
	
	LookLock_RegisterCosmos();
end

function LookLock_OnEvent()
	if (event == "UPDATE_BINDINGS") then
		LookLock_Remap_Toggle(LookLockRemapOn);
	end
end